package net.cephas.james.mailets;

import javax.mail.MessagingException;

import org.apache.mailet.Mail;


/**
 * MailSummarizer is a Java interface that enables administrators
 * to choose a variety of ways to forward emails to users and 
 * gives developers access to every part of the email in flowing 
 * through James. 
 * 
 * By default the Mail2XMPPMailet is configured to use the
 * SimpleSummarizer implementation which transforms the email
 * by including only the from address, to address
 * and the subject of the email.
 * 
 * Other implementations could include:
 * <ul>
 * <li>MessageFormatSummarizer which could allow an administrator 
 * to supply a resource bundle instead of having to use a Java class 
 * for formatting</li>
 * <li>FileAttachmentSummarizer which could attempt to read the
 * contents of standard email attachments</li>
 * <li>BodySummarizer which could use (for example) Classifier4J
 * to attempt to summarize the body content of an email.</li>
 * </ul> 
 * 
 * Accessing some members of the MimeMessage (ie: subject) may cause a
 * MessagingException. If an exception occurs, let the exception
 * propogate back up the stack so that the Mail2XMPPMailet can 
 * record the error to the mailet log file.
 * 
 * @author Aaron Johnson
 */
public interface MailSummarizer {
    
   public String getSummary(Mail mail) throws MessagingException;
   

}
